=================================
Welcome to hrefs's documentation!
=================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. include:: ../README.rst

User guide
==========

.. toctree::
   :maxdepth: 2

   quickstart

API reference
=============

.. toctree::
   :maxdepth: 2

   api

History
=======

.. toctree::
   :maxdepth: 2

   changelog
